diff graal/GraalCompiler/src/com/sun/c1x/ir/MonitorExit.java @ 2622:91d3952f7eb7

Framestate work : using stateAFter and reducting the number of nodes with framestates. Intermediate state (does not pass tests)
author Gilles Duboscq <gilles.duboscq@oracle.com>
date Tue, 10 May 2011 12:37:46 +0200
parents 1c36b17f7ee0
children 569228710be8
line wrap: on
line diff
--- a/graal/GraalCompiler/src/com/sun/c1x/ir/MonitorExit.java	Tue May 10 11:55:12 2011 +0200
+++ b/graal/GraalCompiler/src/com/sun/c1x/ir/MonitorExit.java	Tue May 10 12:37:46 2011 +0200
@@ -40,11 +40,11 @@
      * @param object the instruction produces the object value
      * @param lockAddress the address of the on-stack lock object or {@code null} if the runtime does not place locks on the stack
      * @param lockNumber the number of the lock
      * @param stateBefore the state before executing this instruction
      * @param graph
      */
-    public MonitorExit(Value object, Value lockAddress, int lockNumber, FrameState stateBefore, Graph graph) {
-        super(object, lockAddress, stateBefore, lockNumber, INPUT_COUNT, SUCCESSOR_COUNT, graph);
+    public MonitorExit(Value object, Value lockAddress, int lockNumber, FrameState stateAfter, Graph graph) {
+        super(object, lockAddress, stateAfter, lockNumber, INPUT_COUNT, SUCCESSOR_COUNT, graph);
     }
 
     @Override
@@ -40,11 +40,11 @@
      * @param lockAddress the address of the on-stack lock object or {@code null} if the runtime does not place locks on the stack
      * @param lockNumber the number of the lock
-     * @param stateBefore the state before executing this instruction
+     * @param stateBefore the state after executing this instruction
      * @param graph
      */